/**
 * Copyright 2019, Optimizely
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export { v4 as generateUUID } from 'uuid';
export declare type Omit<T, K> = Pick<T, Exclude<keyof T, K>>;
export declare function getTimestamp(): number;
/**
 * Validates a value is a valid TypeScript enum
 *
 * @export
 * @param {object} enumToCheck
 * @param {*} value
 * @returns {boolean}
 */
export declare function isValidEnum(enumToCheck: {
    [key: string]: any;
}, value: any): boolean;
export declare function groupBy<K>(arr: K[], grouperFn: (item: K) => string): Array<K[]>;
export declare function objectValues<K>(obj: {
    [key: string]: K;
}): K[];
export declare function objectEntries<K>(obj: {
    [key: string]: K;
}): [string, K][];
export declare function find<K>(arr: K[], cond: (arg: K) => boolean): K | undefined;
export declare function keyBy<K>(arr: K[], keyByFn: (item: K) => string): {
    [key: string]: K;
};
export declare function sprintf(format: string, ...args: any[]): string;
export declare enum NOTIFICATION_TYPES {
    ACTIVATE = "ACTIVATE:experiment, user_id,attributes, variation, event",
    DECISION = "DECISION:type, userId, attributes, decisionInfo",
    LOG_EVENT = "LOG_EVENT:logEvent",
    OPTIMIZELY_CONFIG_UPDATE = "OPTIMIZELY_CONFIG_UPDATE",
    TRACK = "TRACK:event_key, user_id, attributes, event_tags, event"
}
export interface NotificationCenter {
    sendNotifications(notificationType: NOTIFICATION_TYPES, notificationData?: any): void;
}
export { default as PersistentKeyValueCache } from './persistentKeyValueCache';
export { default as ReactNativeAsyncStorageCache } from './reactNativeAsyncStorageCache';
